BCEAfterSigmoidLoss
===================

.. currentmodule:: pykeen.losses

.. autoclass:: BCEAfterSigmoidLoss
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~BCEAfterSigmoidLoss.forward

   .. rubric:: Methods Documentation

   .. automethod:: forward
